import { UserContent } from 'ai';
import { Integration } from '../integration';
import { Logger } from '../logger';
import { AllTools, ToolApi } from '../tools/types';
import { LLM } from '../llm';
import { ModelConfig } from '../llm/types';
export declare class Agent<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    name: string;
    readonly llm: LLM<TTools, TIntegrations, TKeys>;
    readonly instructions: string;
    readonly model: ModelConfig;
    readonly enabledTools: Partial<Record<TKeys, boolean>>;
    logger: Logger;
    constructor(config: {
        name: string;
        instructions: string;
        model: ModelConfig;
        enabledTools?: Partial<Record<TKeys, boolean>>;
    });
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    /**
     * Set the logger for the agent
     * @param logger
     */
    __setLogger(logger: Logger): void;
    text({ messages, onStepFinish, maxSteps, }: {
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<import("ai").GenerateTextResult<{}>>;
    stream({ messages, onStepFinish, onFinish, maxSteps, }: {
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    }): Promise<import("ai").StreamTextResult<{}>>;
}
//# sourceMappingURL=index.d.ts.map