import { CoreMessage, CoreTool as CT, LanguageModelV1 } from 'ai';
import { ZodSchema } from 'zod';
import { AllTools, CoreTool, ToolApi } from '../tools/types';
import { Integration } from '../integration';
import { Logger } from '../logger';
import { ModelConfig } from './types';
export declare class LLM<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    #private;
    logger: Logger;
    constructor(logger?: Logger);
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    getModelType(model: ModelConfig): string;
    createOpenAICompatibleModel(baseURL: string, apiKey: string, defaultModelName: string, modelName?: string): LanguageModelV1;
    createModelDef({ model, }: {
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
        };
    }): LanguageModelV1;
    getParams({ tools, resultTool, model, }: {
        tools: Record<string, CoreTool>;
        resultTool?: {
            description: string;
            parameters: ZodSchema;
        };
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
        };
    }): {
        toolsConverted: Record<string, CT>;
        modelDef: LanguageModelV1;
        answerTool: {};
        toolChoice: "auto" | "required";
    };
    convertTools(enabledTools?: Partial<Record<TKeys, boolean>>): Record<TKeys, CoreTool>;
    text({ model, messages, onStepFinish, maxSteps, enabledTools, }: {
        enabledTools?: Partial<Record<TKeys, boolean>>;
        model: ModelConfig;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<import("ai").GenerateTextResult<{}>>;
    stream({ model, messages, onStepFinish, onFinish, maxSteps, enabledTools, }: {
        model: ModelConfig;
        enabledTools: Partial<Record<TKeys, boolean>>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    }): Promise<import("ai").StreamTextResult<{}>>;
}
//# sourceMappingURL=index.d.ts.map