import { Integration } from '../integration';
import { Agent } from '../agent';
import { Logger, RegisteredLogger } from '../logger';
import { SyncConfig } from '../sync/types';
import { AllTools } from '../tools/types';
import { MastraEngine } from '../engine';
import { MastraVector } from '../vector';
import { LLM } from '../llm';
import { z } from 'zod';
import { Workflow } from '../workflows';
export declare class Mastra<TIntegrations extends Integration[], MastraTools extends Record<string, any>, TSyncs extends Record<string, SyncConfig<TIntegrations, MastraTools, any>> = Record<never, never>> {
    private engine?;
    private vectors?;
    private tools;
    private agents;
    llm: LLM<MastraTools, TIntegrations, keyof AllTools<MastraTools, TIntegrations>>;
    private integrations;
    private logger;
    private syncs;
    private workflows;
    constructor(config: {
        tools?: MastraTools;
        syncs?: TSyncs;
        agents?: Agent<MastraTools, TIntegrations>[];
        integrations?: TIntegrations;
        engine?: MastraEngine;
        vectors?: Record<string, MastraVector>;
        logger?: Logger;
        workflows?: Workflow[];
    });
    sync<K extends keyof TSyncs>(key: K, params: TSyncs[K] extends SyncConfig<any, any, infer P> ? P : never): Promise<void>;
    getAgent(name: string): Agent<MastraTools, TIntegrations, keyof MastraTools | keyof (TIntegrations extends Integration[] ? (import("../tools/types").IntegrationTools<TIntegrations[number]> extends infer T ? T extends import("../tools/types").IntegrationTools<TIntegrations[number]> ? T extends any ? (k: T) => void : never : never : never) extends (k: infer I) => void ? I : never : {})>;
    getIntegration<I extends TIntegrations[number]['name']>(name: I): Extract<TIntegrations[number], {
        name: I;
    }>;
    getTool<T extends keyof MastraTools>(name: T): AllTools<MastraTools, TIntegrations>[T] & {
        execute: (params: z.infer<MastraTools[T]["schema"]>) => Promise<any>;
    };
    availableIntegrations(): {
        name: string;
        integration: Integration;
    }[];
    getTools(): AllTools<MastraTools, TIntegrations>;
    setLogger({ key, logger }: {
        key: RegisteredLogger;
        logger: Logger;
    }): void;
    getLogger(key: RegisteredLogger): Logger<import("../logger").BaseLogMessage> | undefined;
}
//# sourceMappingURL=index.d.ts.map