import { ZodSchema } from 'zod';
import { Integration } from '../integration';
import { LLM } from '../llm';
import { MastraEngine } from '../engine';
import { Agent } from '../agent';
export type CoreTool = {
    description: string;
    parameters: ZodSchema;
    execute: (params: any) => Promise<any>;
};
export interface IntegrationApiExcutorParams<T extends Record<string, unknown>> {
    data: T;
    getIntegration: <I extends Integration[]>(name: I[number]['name']) => Extract<I[number], {
        name: I[number]['name'];
    }>;
    llm: LLM<Integration[], any, any>;
    engine?: MastraEngine | undefined;
    agents: Map<string, Agent<Integration[], any>>;
}
export type ToolApi<IN extends Record<string, unknown> = Record<string, unknown>, OUT extends Record<string, unknown> = Record<string, unknown>> = {
    schema: ZodSchema<IN>;
    label: string;
    description: string;
    documentation?: string;
    executor: (params: IntegrationApiExcutorParams<IN>) => Promise<OUT>;
};
export type IntegrationTools<T extends Integration> = T['tools'];
type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends (k: infer I) => void ? I : never;
export type MergeIntegrationTools<T extends Integration[]> = UnionToIntersection<IntegrationTools<T[number]>>;
export type AllTools<TTools, TIntegrations extends Integration[] | undefined = undefined> = TTools & (TIntegrations extends Integration[] ? MergeIntegrationTools<TIntegrations> : {});
export {};
//# sourceMappingURL=types.d.ts.map